import json
import os
from datetime import datetime

from django.conf import settings
from django.contrib.messages import get_messages
from django.contrib.staticfiles.storage import staticfiles_storage
from django.template.backends.jinja2 import Jinja2 as OriginalJinja2
from django.urls import reverse
from django.utils.translation import gettext
from jinja2 import Environment
from zeppsta.utils import camel_to_snake_case


class Jinja2(OriginalJinja2):
    app_dirname = os.path.join('templates', 'jinja2')


def view_css_class(view):
    return camel_to_snake_case(view.__class__.__name__).replace('_', '-')


def environment(**options):
    options.update({
        'extensions': [
            'jinja2.ext.do',
            'jinja2.ext.i18n',
        ]
    })
    env = Environment(**options)
    env.filters.update({
        'view_css_class': view_css_class,
    })
    try:
        from sorl.thumbnail.shortcuts import get_thumbnail
        env.filters.update({
            'thumbnail_url': lambda _file: get_thumbnail(_file, settings.THUMBNAIL_DEFAULT_GEOMETRY_STRING).url,
            'json': json.dumps,
        })
    except ImportError:
        pass
    env.globals.update({
        'datetime': datetime,
        'get_messages': get_messages,
        'hasattr': hasattr,
        'settings': settings,
        'static': staticfiles_storage.url,
        'gettext': gettext,
        'trans': gettext,
        'url': reverse,
    })
    return env
